/**
 * Copyright (c) 2016-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to
 * use, copy, modify, and distribute this software in source code or binary
 * form for use in connection with the web services and APIs provided by
 * Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.facebook.audiencenetwork.adssample.adunit;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.akamai.amp.ads.fban.AmpFacebookAudienceNetworkManager;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.uimobile.generic.media.PlayerControlsOverlay;
import com.facebook.audiencenetwork.adssample.R;


public class InstreamVideoFragment extends Fragment {

    private static final String AMP_LICENSE = "CO2-R2OOAgJt6r6fKqNxZmQG-Fjw6HdTgktWw82tyyodRH6Bor0hzWKrQ6_bHWnQhBl94RwjVYE213tW4-A4gQ==";
    private static final String VOD_HLS = "https://media-demo-host.akamaized.net/test/video/kluge/hls/all.m3u8";

    private static final String PLACEMENT_ID = "YOUR_PLACEMENT_ID";
    private static final int[] ADS_AT_SECONDS = {10, 30, 50};
    private static final int[] OPTIONAL_ADS = {20, 40, 60};


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private PlayerControlsOverlay mPlayerControlsOverlay;

    private AmpFacebookAudienceNetworkManager adManager;


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_instream_video, container, false);

        mPlayerControlsOverlay = view.findViewById(R.id.playerControls);
        videoPlayerContainer = view.findViewById(R.id.video_player_container);
        setInlineUI();

        adManager = new AmpFacebookAudienceNetworkManager(PLACEMENT_ID, ADS_AT_SECONDS);
        adManager.setVideoPlayerContainer(videoPlayerContainer);
        adManager.addEventsListener(mPlayerControlsOverlay);
        //adManager.enablePreroll(true);
        //adManager.enablePostroll(true);
        adManager.addOptionalMidrolls(OPTIONAL_ADS);

        //To request a midroll at any point in time:
        //adManager.requestAd();

        videoPlayerContainer.addVideoPlayerContainerCallback(containerCallback);
        videoPlayerContainer.prepareResource(VOD_HLS);

        return view;
    }

    private final VideoPlayerContainer.VideoPlayerContainerCallback containerCallback = new VideoPlayerContainer.VideoPlayerContainerCallback() {
        @Override
        public void onResourceReady(MediaResource mediaResource) {
            videoPlayerView.play(mediaResource);
        }

        @Override
        public void onVideoPlayerCreated() {
            videoPlayerView = videoPlayerContainer.getVideoPlayer();
            videoPlayerView.setLicense(AMP_LICENSE);
            videoPlayerView.setFullScreen(true);
            videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
            videoPlayerView.setLogEnabled(true);

            mPlayerControlsOverlay.setVideoPlayerContainer(videoPlayerContainer);

            adManager.setVideoPlayerView(videoPlayerView);
        }

        @Override
        public void onResourceError(ErrorType errorType, Exception exception) {
        }

    };

    private void setInlineUI() {
        mPlayerControlsOverlay.overrideControlsLayout(R.layout.androidsdk_mediaplayercontroller);
        setupInlinePlayerControls();
    }

    private void setupInlinePlayerControls() {
        mPlayerControlsOverlay.managePlayPause(R.id.androidsdk_playPauseCtrl,
                R.mipmap.play,
                R.mipmap.pause);
        mPlayerControlsOverlay.manageCurrentPosition(R.id.androidsdk_seekbarTextCtrl);
        mPlayerControlsOverlay.manageTimeRemaining(R.id.video_duration);
        mPlayerControlsOverlay.manageScrubbing(R.id.androidsdk_seekbarCtrl,
                R.id.androidsdk_seekToLiveAction);

        mPlayerControlsOverlay.manageFullScreen(R.id.androidsdk_fullscreenCtrl,
                R.mipmap.amp_non_fullscreen_btn,
                R.mipmap.amp_fullscreen_btn);
    }

}
