/**
 * Copyright (c) 2016-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to
 * use, copy, modify, and distribute this software in source code or binary
 * form for use in connection with the web services and APIs provided by
 * Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.facebook.audiencenetwork.adssample.adunit;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.akamai.amp.AmpPlayer;
import com.akamai.amp.ads.fban.AmpFacebookAudienceNetworkManager;
import com.facebook.audiencenetwork.adssample.R;


public class InstreamVideoFragmentUnpublishedApi extends Fragment {

    private static final String AMP_LICENSE = "CO2-R2OOAgJt6r6fKqNxZmQG-Fjw6HdTgktWw82tyyodRH6Bor0hzWKrQ6_bHWnQhBl94RwjVYE213tW4-A4gQ==";
    private static final String VOD_HLS = "https://media-demo-host.akamaized.net/test/video/kluge/hls/all.m3u8";

    private static final String PLACEMENT_ID = "YOUR_PLACEMENT_ID";
    private static final int[] ADS_AT_SECONDS = {10, 20, 30};


    private AmpPlayer amp;
    private AmpFacebookAudienceNetworkManager adManager;


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_instream_video_unpublished_api, container, false);

        amp = view.findViewById(R.id.amp);

        adManager = new AmpFacebookAudienceNetworkManager(PLACEMENT_ID, ADS_AT_SECONDS);
        adManager.enablePreroll(true);
        adManager.enablePostroll(true);
        //To request a midroll at any point in time:
        //adManager.requestAd();

        amp.setAdsPlugin(adManager);
        amp.play(VOD_HLS, getActivity(), AMP_LICENSE);

        return view;
    }

    // Android Lifecycle

    @Override
    public void onResume() {
        if (amp != null) amp.onResume();
        super.onResume();
    }

    @Override
    public void onPause() {
        if (amp != null) amp.onPause();
        super.onPause();
    }

    @Override
    public void onDestroy() {
        if (amp != null) amp.onDestroy();
        super.onDestroy();
    }

}
