package com.akamai.ampfreewheelsample;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.WindowManager;

import com.akamai.amp.ads.AdsCount;
import com.akamai.amp.ads.AdsInfo;
import com.akamai.amp.ads.IAdsComponentListener;
import com.akamai.amp.ads.freewheel.AdSlot;
import com.akamai.amp.ads.freewheel.AmpFreewheelManager;
import com.akamai.amp.ads.freewheel.Freewheel;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerContainer.VideoPlayerContainerCallback;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.uimobile.listeners.IMediaPlayerControllerListener;
import com.akamai.amp.uimobile.media.MediaPlayerController;

import tv.freewheel.utils.Logger;


public class FreeWheelActivity extends AppCompatActivity
        implements VideoPlayerContainerCallback, IAdsComponentListener, IMediaPlayerControllerListener {

    private static final String TAG = FreeWheelActivity.class.getName();

    // ***NOTE***
    // Each client gets their own network ID, AdManager URLs, and ad server URLs
    // Please see your FreeWheel account manager or sales engineer for the
    // appropriate values to use in your production player.
    public static String FW_ADS_URL = "http://example.com/";
    public static int FW_NETWORK_ID = 12345;

    // Request parameters --- these may change from request to request
    // depending on how your content is arranged in the MRM system

    public static String FW_PROFILE = "replace_with_your_profile";
    public static String FW_SITE_SECTION_ID = "replace_with_your_site_section";
    public static String FW_VIDEO_ASSET_ID = "replace_with_your_video_asset";


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private MediaPlayerController mediaPlayerController;

    private AmpFreewheelManager freewheelManager;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.i(TAG,"onCreate");

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        mediaPlayerController = (MediaPlayerController) findViewById(R.id.controller);
        mediaPlayerController.hideFullscreenButton();
        videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.videoContainer);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);

        freewheelManager = Freewheel.create(this, FW_NETWORK_ID, FW_ADS_URL,
                FW_SITE_SECTION_ID, FW_VIDEO_ASSET_ID, FW_PROFILE);
        freewheelManager.setExternalLogLevel(Logger.WARN);
        freewheelManager.addEventsListener(this);
        freewheelManager.setVideoPlayerContainer(videoPlayerContainer);
        //freewheelManager.warnOnAdClick("");
        //freewheelManager.addTemporalSlots(createAdSlots());

        videoPlayerContainer.prepareResource(getString(R.string.dash));
    }

    private AdSlot[] createAdSlots() {
        return new AdSlot[]{
                new AdSlot("pre1",  AmpFreewheelManager.PREROLL,  0),
                new AdSlot("post1", AmpFreewheelManager.POSTROLL, 60),
                new AdSlot("mid1",  AmpFreewheelManager.MIDROLL,  30),
                new AdSlot("mid2",  AmpFreewheelManager.MIDROLL,  900),
                new AdSlot("mid3",  AmpFreewheelManager.MIDROLL,  1800)};
    }

    private void configVideoPlayer(){
        mediaPlayerController.setVideoPlayerContainer(videoPlayerContainer);
        mediaPlayerController.setEventsListener(this);

        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(getString(R.string.license_key));
        videoPlayerView.setLogEnabled(true);

        freewheelManager.setVideoPlayerView(videoPlayerView);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG,"onVideoPlayerCreated");
    }

    @Override
    public void onResourceReady(MediaResource resource) {
        Log.i(TAG,"onResourceReady");
        this.configVideoPlayer();
        videoPlayerView.play(resource);
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {

        Log.e(TAG,"onResourceError");
    }

    @Override
    protected void onResume(){
        Log.i(TAG, "onResume");
        freewheelManager.onResume();
        if(videoPlayerView != null) {
            videoPlayerView.onResume();
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.i(TAG,"onPause");
        freewheelManager.onPause();
        if(videoPlayerView != null){
            videoPlayerView.onPause();
        }
        super.onPause();
    }

    @Override
    protected void onStop() {
        Log.i(TAG,"onStop");
        super.onStop();
        freewheelManager.onStop();
    }

    @Override
    protected void onDestroy() {
        Log.i(TAG,"onDestroy");
        super.onDestroy();
        videoPlayerView.onDestroy();
        //freewheelManager.onDestroy();
    }

    @Override
    protected void onStart() {
        Log.i(TAG,"onStart");
        super.onStart();
        freewheelManager.onStart();
    }

    @Override
    protected void onRestart() {
        Log.i(TAG,"onRestart");
        super.onRestart();
        freewheelManager.onRestart();
    }


    // IAdsComponentListener
    @Override
    public void onAdBreakStarted(){
        Log.i(TAG,"onAdBreakStarted");
        mediaPlayerController.showControlBar(false);
    }

    @Override
    public void onAdsStarted(AdsInfo adsInfo) {
        Log.i(TAG,"onAdsStarted " + adsInfo);
        mediaPlayerController.showControlBar(false);
    }

    @Override
    public void onAdBreakEnded(){
        Log.i(TAG,"onAdBreakEnded");
        mediaPlayerController.showControlBar(true);
    }

    @Override
    public void onAdsEnded() {
        Log.i(TAG,"onAdsEnded");
        mediaPlayerController.showControlBar(true);
    }

    @Override
    public void onListenerRegistered() {
        Log.i(TAG,"onListenerRegistered");
    }

    @Override
    public void onAdsInitialized() {
        Log.i(TAG,"onAdsInitialized");
    }

    @Override
    public void onAdsLoaded(AdsCount adsCount) {
        Log.i(TAG,"onAdsLoaded " + adsCount);
    }

    @Override
    public void onAllPostrollsEnded() {
        Log.i(TAG,"onAllPostrollsEnded");
    }

    @Override
    public void onAdsTrackProgress(int i) {
        Log.i(TAG,"onAdsTrackProgress " + i);
    }

    @Override
    public void onAdsPlayheadUpdate(int i) {
        Log.i(TAG,"onAdsPlayheadUpdate " + i);
    }

    @Override
    public void onAdEvent() {
        Log.i(TAG,"onAdEvent ");}

    @Override
    public void onAdsError(String errorMessage) {
        Log.i(TAG,"onAdsError " + errorMessage);
    }

    @Override
    public void onPauseContentRequested() {
        Log.i(TAG, "onPauseContentRequested");
    }

    @Override
    public void onResumeContentRequested() {
        Log.i(TAG, "onResumeContentRequested");
    }

    @Override
    public void onAdsPaused() {
        Log.i(TAG,"onAdsPaused");
    }

    @Override
    public void onAdsResumed() {
        Log.i(TAG,"onAdsResumed");
    }

    @Override
    public void onAdsTapped() {Log.i(TAG,"onAdsTapped");}

    @Override
    public void onButtonClicked(int i) {
        Log.i(TAG,"onButtonClicked");
    }

}
