package com.akamai.ampyospacesample;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.amp.ads.yospace.AmpYospaceManager;
import com.akamai.amp.ads.yospace.Yospace;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.AMPLibraryInfo;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.uimobile.listeners.IMediaPlayerControllerListener;
import com.akamai.amp.uimobile.media.MediaPlayerController;

public class MainActivity extends Activity
        implements IMediaPlayerControllerListener, VideoPlayerContainer.VideoPlayerContainerCallback {

    private static final String TAG = "AMP-UI-Sample";
    private static final String ANDROID_SDK_LICENSE = "aqaxX_uF-SX1mmvVDyDgJzUc_T9VDRyFsABHYYMKg5d2Fhge21EaIsahVu-ZYT7luZR54c-bBRvjSl4G_qLjqg==";
    private static final String MEDIA_ASSET_URL = "http://csm-e.cds1.yospace.com/csm/extlive/yospace02,sampledroid.m3u8?yo.br=false&yo.ac=true";
    private VideoPlayerContainer mVideoPlayerContainer;
    private VideoPlayerView mVideoPlayerView;
    private MediaPlayerController mMediaPlayerController;
    private ProgressBar mProgressBar;

    private MediaResource resource;
    private boolean mFullScreenMode;
    private int mCurrentPosition;
    private AmpYospaceManager ampYospaceManager;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        validateFullScreenState();
        setContentView(R.layout.activity_main);

        if (savedInstanceState != null) {
            mFullScreenMode = savedInstanceState.getBoolean("FULLSCREEN");
            mCurrentPosition = savedInstanceState.getInt("CURRENT_POSITION");
        } else {
            mFullScreenMode = false;
            mCurrentPosition = 0;
        }

        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.addVideoPlayerContainerCallback(this);


        ampYospaceManager = Yospace.create(this,MEDIA_ASSET_URL);
        ampYospaceManager.setVideoPlayerContainer(mVideoPlayerContainer);
        mVideoPlayerContainer.enableAutoRecovery(ampYospaceManager.getConnectionSwitchCallback());
        ampYospaceManager.doProxyInit();
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        resource = mediaResource;
        mVideoPlayerView = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayerView.setLicense(ANDROID_SDK_LICENSE);
        mVideoPlayerView.setLogEnabled(true);
        ampYospaceManager.setVideoPlayerView(mVideoPlayerView);

        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
        setFullScreenState(mFullScreenMode);
        mMediaPlayerController.setVideoPlayerContainer(mVideoPlayerContainer);
        mMediaPlayerController.setEventsListener(MainActivity.this);
        mVideoPlayerView.enableDVRfeatures(false);

        mVideoPlayerView.setProgressBarControl(mProgressBar);
        mVideoPlayerView.play(mediaResource, mCurrentPosition);

        Log.i(TAG, "AMP v" + AMPLibraryInfo.VERSION);
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {
        Log.e(TAG, "onResourceError()");
    }

    private void validateFullScreenState() {
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE)
        {
            requestWindowFeature(Window.FEATURE_NO_TITLE);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        }
        else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            requestWindowFeature(Window.FEATURE_ACTION_BAR);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN, WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN);
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        if(mVideoPlayerView != null) {
            mVideoPlayerView.onResume();
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        if(mVideoPlayerView != null)
            mVideoPlayerView.onPause();
    }

    @Override
    protected void onDestroy() {
        if (mVideoPlayerView != null) {
            mVideoPlayerView.onDestroy();
            ampYospaceManager.onStop();
        }
        super.onDestroy();
    }

    @Override
    protected void onStart() {
        super.onStart();
    }

    @Override
    protected void onStop() {
        super.onStop();
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        savedInstanceState.putBoolean("FULLSCREEN", mFullScreenMode);
        savedInstanceState.putInt("CURRENT_POSITION", mCurrentPosition);
        // Always call the superclass so it can save the view hierarchy state
        super.onSaveInstanceState(savedInstanceState);
    }

    private void setFullScreenMode(boolean fullscreen)
    {
        if(fullscreen == mFullScreenMode)
            return;
        mFullScreenMode = fullscreen;
        if (fullscreen) {
            mVideoPlayerView.setFullScreen(true);
            mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);

        } else {
            mVideoPlayerView.setFullScreen(false);
            mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_NONE);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
        setFullScreenState(mFullScreenMode);
    }

    private void setFullScreenState(boolean fullscreen){
        if (fullscreen) {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);
        } else {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }
    }

    @Override
    public void onButtonClicked(int arg0) {
        if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
            setFullScreenMode(!mFullScreenMode);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return false;
    }

}