package com.akamai.ampdemo;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.widget.ProgressBar;

import com.akamai.ampdemo.R;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.acceleration.AmpAkamaiMediaAcceleration;
import com.akamai.amp.media.elements.AMPLibraryInfo;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;


public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private static final String LOG_TAG = MainActivity.class.getSimpleName();

    private static final String AMP_SDK_LICENSE = "Tj0DEjr8GzMia8wLQGcRXa1TqUTpmNPhxDwIfcVnzG8BW67ajJNVe2sByPwZ-DVlpsDtjL83i1r1p8TjDxP67A==";
    private static final String MEDIA_ASSET_URL_HLS = "https://media-demo-host.akamaized.net/test/video/kluge/hls/all.m3u8";
    private static final String MEDIA_ASSET_URL_DASH = "https://media-acceleration.akamaized.net/video/bbb/bbb_30fps.mpd";


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);

        AmpAkamaiMediaAcceleration.prepareResource(MEDIA_ASSET_URL_HLS, videoPlayerContainer);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(AMP_SDK_LICENSE);
        videoPlayerView.setLogEnabled(true);
        videoPlayerView.setProgressBarControl(progressBar);
        videoPlayerView.setKeepScreenOn(true);
        videoPlayerView.play(mediaResource);

        Log.i(LOG_TAG, "AMP SDK v" + AMPLibraryInfo.VERSION + " with MAE v" + AmpAkamaiMediaAcceleration.getMaeVersion());
    }

    @Override
    public void onVideoPlayerCreated() {

        Log.i(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {

        Log.e(LOG_TAG, "onResourceError()");
    }

    @Override
    public void onStop() {
        Log.i(LOG_TAG, "onStop()");

        if (videoPlayerView != null)
            videoPlayerView.stop();

        AmpAkamaiMediaAcceleration.stop();

        super.onStop();
    }

}
