package com.akamai.heartbeatsample;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.amp.ads.AdsInfo;
import com.akamai.amp.analytics.adobeheartbeat.AmpAdobeHeartbeatAnalyticsTracker;
import com.akamai.amp.config.data.heartbeat.HeartbeatConfigurationData;
import com.akamai.amp.config.data.heartbeat.HeartbeatData;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.uimobile.media.MediaPlayerController;
import com.akamai.amp.utils.LogManager;

import java.util.HashMap;
import java.util.Map;
import java.util.TimeZone;


public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private static final String LOG_TAG = "AMP + Adobe Heartbeat";
    private static final String AMP_LICENSE = "E59X_D1f7n6J2aD8PgMQLjW9DdfxaWMaGmARUklLgYYmXRl-MNQF_DU17fmge_Pen6zbrgjDPcbgzetQlvh7VA==";
    private static final String VIDEO_URL_VOD = "http://sblancovodmdev-f.akamaihd.net/i/temp/bbb.mp4/master.m3u8";
    private static final String VIDEO_URL_LIVE = "http://multiformatlive-f.akamaihd.net/i/demostream_1@2131/master.m3u8";
    private static final java.util.TimeZone TIME_ZONE = TimeZone.getTimeZone("America/New_York");

    private static final String HEARTBEAT_TRACKING_SERVER = "http://obumobile1.hb.omtrdc.net";
    private static final String HEARTBEAT_PUBLISHER       = "TEST";
    private static final String HEARTBEAT_CHANNEL         = "test-channel";
    private static final String HEARTBEAT_OVP             = "test-ovp";
    private static final String AUDIENCE_MANAGER_DPID     = "67312378756723456";
    private static final String AUDIENCE_MANAGER_DPUUID   = "550e8400-e29b-41d4-a716-446655440000";
    private static final String ADOBE_USER_ID             = "test-vid";

    private static final String SAMPLE_MEDIA_ID = "TestID123";
    private static final String SAMPLE_MEDIA_FRIENDLY_NAME = "TestContentTitle";



    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;
    private MediaPlayerController mMediaPlayerController;

    private AmpAdobeHeartbeatAnalyticsTracker analytics;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        progressBar = findViewById(R.id.progressBar);
        mMediaPlayerController = findViewById(R.id.playerControls);
        videoPlayerContainer = findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(VIDEO_URL_VOD);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setProgressBarControl(progressBar);
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setFullScreen(true);
        videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
        videoPlayerView.setLogEnabled(true);

        mMediaPlayerController.setVideoPlayerContainer(videoPlayerContainer);
        mMediaPlayerController.hideFullscreenButton();

        //mediaResource.setTitle(SAMPLE_MEDIA_FRIENDLY_NAME);

        analytics = new AmpAdobeHeartbeatAnalyticsTracker(videoPlayerView, buildHeartbeatData());
        analytics.setTimeZone(TIME_ZONE);

        videoPlayerView.play(mediaResource);
    }

    private HeartbeatData buildHeartbeatData() {
        HeartbeatData data = new HeartbeatData(buildHeartbeatConfigurationData());
        data.setStandardVideoMetadata(getStandardVideoMetadata());
        return data;
    }

    private HeartbeatConfigurationData buildHeartbeatConfigurationData() {
        HeartbeatConfigurationData data = new HeartbeatConfigurationData();
        data.setTrackingServer(HEARTBEAT_TRACKING_SERVER);
        data.setPublisher(HEARTBEAT_PUBLISHER);
        data.setChannel(HEARTBEAT_CHANNEL);
        data.setOvp(HEARTBEAT_OVP);
        data.setAudienceManagerDpid(AUDIENCE_MANAGER_DPID);
        data.setAudienceManagerDpuuid(AUDIENCE_MANAGER_DPUUID);
        data.setAdobeUserId(ADOBE_USER_ID);
        //data.setAdsInfo(buildSampleAdInfo());
        return data;
    }

    private AdsInfo buildSampleAdInfo() {
        AdsInfo a = new AdsInfo();
        a.name = "Sample Ad";
        a.adId = "123";
        a.length = 20;
        a.positionInStream = 30;
        return a;
    }

    private Map<String, String> getStandardVideoMetadata() {
        Map<String, String> values = new HashMap<>();
        values.put(AmpAdobeHeartbeatAnalyticsTracker.KEY_MEDIA_ID, SAMPLE_MEDIA_ID);
        values.put(AmpAdobeHeartbeatAnalyticsTracker.KEY_MEDIA_FRIENDLY_NAME, SAMPLE_MEDIA_FRIENDLY_NAME);
        values.put("testKey", "testValue");
        return values;
    }

    @Override
    public void onVideoPlayerCreated() {
        LogManager.log(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {
        LogManager.error(LOG_TAG, "onResourceError() " + exception);
    }


    //It's mandatory to let the SDK know when the app goes and comes to the background

    @Override
    protected void onPause() {
        Log.d(LOG_TAG, "onPause");
        if (videoPlayerView != null) videoPlayerView.onPause();
        super.onPause();
    }

    @Override
    protected void onResume() {
        Log.d(LOG_TAG, "onResume");
        if (videoPlayerView != null) videoPlayerView.onResume();
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        Log.d(LOG_TAG, "onDestroy");
        if (videoPlayerView != null) videoPlayerView.onDestroy();
        super.onDestroy();
    }

}
