package com.akamai.ampdemo;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.amp.ads.ima.AmpIMAManager;
import com.akamai.amp.ads.ima.IMA;
import com.akamai.amp.analytics.comscorestreamsense.AmpComscoreStreamsenseAnalyticsTracker;
import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;

import com.akamai.amp.config.data.streamsense.StreamsenseClipLabels;
import com.akamai.amp.config.data.streamsense.StreamsenseData;
import com.akamai.amp.config.data.streamsense.StreamsensePlaylistLabels;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.uimobile.media.MediaPlayerController;
import com.akamai.amp.utils.LogManager;

import java.util.LinkedHashMap;
import java.util.Map;


public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String LOG_TAG = "AMPv6";
    private final static String AMP_LICENSE = "i2xvVC162TUY_7HbZRVu8M1hlbGpdcp_BMTtBarTufIPnW8tGZ9hMGQiFmYlHRK-MImPmABr2EiqfJCipyBdNA==";
    private final static String VIDEO_URL = "http://sblancovodmdev-f.akamaihd.net/i/temp/bbb.mp4/master.m3u8";
    private final static String ADS_URL = "http://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator=";

    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;
    private MediaPlayerController mediaPlayerController;

    private AmpIMAManager ads;
    private AmpComscoreStreamsenseAnalyticsTracker analytics;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        progressBar = findViewById(R.id.progressBar);
        mediaPlayerController = findViewById(R.id.playerControls);
        videoPlayerContainer = findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(VIDEO_URL);
    }

    @Override
    public void onVideoPlayerCreated() {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setProgressBarControl(progressBar);
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setLogEnabled(true);
        videoPlayerView.setFullScreen(true);
        videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

        mediaPlayerController.setVideoPlayerContainer(videoPlayerContainer);

        analytics = new AmpComscoreStreamsenseAnalyticsTracker(videoPlayerView, buildStreamsenseData());
        initGoogleAds();
    }

    private void initGoogleAds() {
        ads = IMA.create(this);
        ads.setVideoPlayerContainer(videoPlayerContainer);
        ads.setVideoPlayerView(videoPlayerView);
        ads.addEventsListener(analytics);
        ads.setAdsUrl(ADS_URL);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView.play(mediaResource);
    }

    private StreamsenseData buildStreamsenseData() {
        StreamsenseData data = new StreamsenseData(videoPlayerView);
        data.setAppData(StreamsenseSampleApplication.getStreamsenseAppData());
        data.setPlaylistLabels(buildPlaylistLabels());
        data.setVideoLabels(buildVideoLabels());
        data.setAdLabels(buildAdLabels());
        return data;
    }

    private StreamsensePlaylistLabels buildPlaylistLabels() {
        StreamsensePlaylistLabels p = new StreamsensePlaylistLabels();
        p.putValue("ns_st_pl", "My Playlist"); //1 Playlist Title
        p.putValue("ns_st_ca", "300000"); //2 Playlist Length (millis)
        p.putValue("ns_st_cp", "2"); //3 Total number of clips
        return p;
    }

    /*
     * Be sure to fill with your video's data. You can query the available labels with:
     * StreamsenseClipLabels.getAllMetadata() and StreamsenseClipLabels.getMandatoryMetadata()
     * Some fields will be automatically filled by AMP, for example the "ns_st_cl" (clip length)
     */
    private StreamsenseClipLabels buildVideoLabels() {
        Map<String, String> m = new LinkedHashMap<>();

        m.put("ns_st_cn", "123"); //1 Clip Number
        m.put("ns_st_ci", "SampleCONTENT"); //2 Content ID
        m.put("ns_st_cl", "MANDATORY"); //3 Clip Length (millis)
        m.put("ns_st_pn", "MANDATORY"); //4 Part number
        m.put("ns_st_tp", "MANDATORY"); //5 Total parts
        //m.put("ns_st_el", "OPTIONAL"); //6 Episode Length (millis)
        m.put("ns_st_pu", "MANDATORY"); //7 Publisher Brand Name
        m.put("ns_st_pr", "MANDATORY"); //8 Program Title
        m.put("ns_st_ep", "MANDATORY"); //9 Episode Title
        m.put("ns_st_sn", "MANDATORY"); //10 Episode Season Number
        m.put("ns_st_en", "MANDATORY"); //11 Episode Number
        //m.put("ns_st_ty", "OPTIONAL"); //11 Stream Type
        m.put("ns_st_ge", "MANDATORY"); //12 Content Genre
        m.put("ns_st_ct", "MANDATORY"); //13 Classification Type
        m.put("ns_st_ti", "MANDATORY"); //14 TMS / Gracenote ID
        m.put("ns_st_ia", "MANDATORY"); //15 Ad Load Flag
        m.put("ns_st_ce", "MANDATORY"); //16 Complete Episode Flag (mandatory only for content)
        //m.put("ns_st_dt", "OPTIONAL"); //17 Production or creation Date
        //m.put("ns_st_tm", "OPTIONAL"); //18 Production or creation Time
        m.put("ns_st_ddt", "MANDATORY"); //19 Digital Airdate
        //m.put("ns_st_dtm", "OPTIONAL"); //20 Digital Airtime
        m.put("ns_st_tdt", "MANDATORY"); //21 TV Airdate
        //m.put("ns_st_ttm", "OPTIONAL"); //22 TV Airtime
        m.put("ns_st_st", "MANDATORY"); //23 Station Title
        //m.put("ns_st_fee", "OPTIONAL"); //24 Monetary Value
        //m.put("ns_st_ad", "OPTIONAL"); //25 Advertisement Flag (mandatory only for advertisements)
        //m.put("ns_st_li", "OPTIONAL"); //26 Live Flag (mandatory only for multicast, simulcast, or unicast streams)
        m.put("ns_st_ct", "MANDATORY"); //27 Classification Type
        //m.put("ns_st_cs", "OPTIONAL"); //28 Video Dimensions (640x480)
        //m.put("ns_st_cu", "OPTIONAL"); //29 Clip URL
        m.put("c3", "MANDATORY"); //30 Video Metrix dictionary classification values
        m.put("c4", "MANDATORY"); //31 Video Metrix dictionary classification values
        m.put("c6", "MANDATORY"); //32 Video Metrix dictionary classification values

        StreamsenseClipLabels l = new StreamsenseClipLabels();
        l.addValues(m);
        return l;
    }

    private StreamsenseClipLabels buildAdLabels() {
        Map<String, String> m = new LinkedHashMap<>();

        m.put("ns_st_cn", "456"); //1 Clip Number
        m.put("ns_st_ci", "SampleAD"); //2 Content ID
        m.put("ns_st_cl", "10000"); //3 Clip Length (millis)
        m.put("ns_st_pn", "MANDATORY AD"); //4 Part number
        m.put("ns_st_tp", "MANDATORY AD"); //5 Total parts
        //m.put("ns_st_el", "OPTIONAL"); //6 Episode Length (millis)
        m.put("ns_st_pu", "MANDATORY"); //7 Publisher Brand Name
        m.put("ns_st_pr", "MANDATORY"); //8 Program Title
        m.put("ns_st_ep", "MANDATORY"); //9 Episode Title
        m.put("ns_st_sn", "MANDATORY"); //10 Episode Season Number
        m.put("ns_st_en", "MANDATORY"); //11 Episode Number
        //m.put("ns_st_ty", "OPTIONAL"); //11 Stream Type
        m.put("ns_st_ge", "MANDATORY"); //12 Content Genre
        m.put("ns_st_ct", "MANDATORY"); //13 Classification Type
        m.put("ns_st_ti", "MANDATORY"); //14 TMS / Gracenote ID
        m.put("ns_st_ia", "MANDATORY"); //15 Ad Load Flag
        m.put("ns_st_ce", "MANDATORY"); //16 Complete Episode Flag (mandatory only for content)
        //m.put("ns_st_dt", "OPTIONAL"); //17 Production or creation Date
        //m.put("ns_st_tm", "OPTIONAL"); //18 Production or creation Time
        m.put("ns_st_ddt", "MANDATORY"); //19 Digital Airdate
        //m.put("ns_st_dtm", "OPTIONAL"); //20 Digital Airtime
        m.put("ns_st_tdt", "MANDATORY"); //21 TV Airdate
        //m.put("ns_st_ttm", "OPTIONAL"); //22 TV Airtime
        m.put("ns_st_st", "MANDATORY"); //23 Station Title
        //m.put("ns_st_fee", "OPTIONAL"); //24 Monetary Value
        //m.put("ns_st_ad", "OPTIONAL"); //25 Advertisement Flag (mandatory only for advertisements)
        //m.put("ns_st_li", "OPTIONAL"); //26 Live Flag (mandatory only for multicast, simulcast, or unicast streams)
        m.put("ns_st_ct", "MANDATORY"); //27 Classification Type
        //m.put("ns_st_cs", "OPTIONAL"); //28 Video Dimensions (640x480)
        //m.put("ns_st_cu", "OPTIONAL"); //29 Clip URL
        m.put("c3", "MANDATORY"); //30 Video Metrix dictionary classification values
        m.put("c4", "MANDATORY"); //31 Video Metrix dictionary classification values
        m.put("c6", "MANDATORY"); //32 Video Metrix dictionary classification values

        StreamsenseClipLabels l = new StreamsenseClipLabels();
        l.addValues(m);
        return l;
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {
        LogManager.error(LOG_TAG, "onResourceError()");
    }


    //It's mandatory to let the SDK know when the app goes and comes to the background

    @Override
    protected void onPause() {
        Log.d(LOG_TAG, "onPause");
        if (videoPlayerView != null) videoPlayerView.onPause();
        super.onPause();
    }

    @Override
    protected void onResume() {
        Log.d(LOG_TAG, "onResume");
        if (videoPlayerView != null) videoPlayerView.onResume();
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        Log.d(LOG_TAG, "onDestroy");
        if (videoPlayerView != null) videoPlayerView.onDestroy();
        super.onDestroy();
    }

}
