/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akamai.downloader.sample;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;

import com.akamai.amp.AmpPlayer;
import com.akamai.amp.media.exowrapper2.ExoWrapper;
import com.akamai.exoplayer2.SimpleExoPlayer;

/** An activity that plays media using {@link SimpleExoPlayer}. */
public class PlayerActivity extends Activity {

  private static final String AMP_LICENSE = "YTHImRNqPaXJAQyNK-jLhrvYYtMkThjC8W2xKHf97ZFswDYoJmPWL1RnsX8Qm6Ldn7WGOJdOoparD4K2eDG3xQ==";


  private AmpPlayer amp;

  @Override
  public void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.player_activity);

    String streamUrl = getStreamUrlFromIntent();
    if (streamUrl == null) return;

    amp = findViewById(R.id.player_view);
    amp.configure(this, AMP_LICENSE);
    amp.setOfflineStreamKeyProvider(SampleApplication.ampDownloadManager);
    String extension = getStreamUrlExtensionFromIntent();
    amp.playWithExtension(streamUrl, extension);
  }

  private String getStreamUrlFromIntent() {
    Intent intent = getIntent();
    String action = intent.getAction();
    if (ExoWrapper.ACTION_VIEW.equals(action)) {
      return String.valueOf(intent.getData());
    } else if (ExoWrapper.ACTION_VIEW_LIST.equals(action)) {
      String[] uriStrings = intent.getStringArrayExtra(ExoWrapper.URI_LIST_EXTRA);
      return uriStrings[0];
    }

    return null;
  }

  private String getStreamUrlExtensionFromIntent() {
    Intent intent = getIntent();
    String action = intent.getAction();
    if (ExoWrapper.ACTION_VIEW.equals(action)) {
      return intent.getStringExtra(ExoWrapper.EXTENSION_EXTRA);
    }
    return null;
  }

  @Override
  public void onResume() {
    if (amp != null) amp.onResume();
    super.onResume();
  }

  @Override
  public void onPause() {
    if (amp != null) amp.onPause();
    super.onPause();
  }

  @Override
  public void onDestroy() {
    if (amp != null) {
      amp.stop();
      amp.onDestroy();
    }

    super.onDestroy();
  }

}
