package com.akamai.downloader.sample;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.net.Uri;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

import com.akamai.exoplayer2.offline.TrackKey;
import com.akamai.exoplayer2.util.Log;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public final class StartDownloadDialogHelper
        implements DialogInterface.OnClickListener {

    private static final String TAG = StartDownloadDialogHelper.class.getSimpleName();

    private final String name;
    private final Uri uri;

    private final AlertDialog.Builder builder;
    private final View dialogView;
    private List<TrackKey> trackKeys;
    private final ArrayAdapter<String> trackTitlesAdapter;
    private final ListView representationList;

    private Context context;

    public StartDownloadDialogHelper(
            Activity activity, String name, Uri uri) {
        this.name = name;
        this.uri = uri;
        builder =
                new AlertDialog.Builder(activity)
                        .setTitle("Download")
                        .setPositiveButton(android.R.string.ok, this)
                        .setNegativeButton(android.R.string.cancel, null);

        // Inflate with the builder's context to ensure the correct style is used.
        LayoutInflater dialogInflater = LayoutInflater.from(builder.getContext());
        dialogView = dialogInflater.inflate(R.layout.start_download_dialog, null);

        trackKeys = new ArrayList<>();
        trackTitlesAdapter =
                new ArrayAdapter<>(
                        builder.getContext(), android.R.layout.simple_list_item_multiple_choice);
        representationList = dialogView.findViewById(R.id.representation_list);
        representationList.setChoiceMode(ListView.CHOICE_MODE_MULTIPLE);
        representationList.setAdapter(trackTitlesAdapter);
        context = activity.getApplicationContext();
    }

    public void buildDialog(List<TrackKey> trackKeys, List<String> trackNames) {
        this.trackKeys = trackKeys;

        for(String trackTitle:trackNames){
            trackTitlesAdapter.add(trackTitle);
        }

        if (!trackKeys.isEmpty()) {
            builder.setView(dialogView);
        }

        builder.create().show();
    }

    public void onError(IOException e) {
        Toast.makeText(context, R.string.download_start_error, Toast.LENGTH_LONG)
                .show();
        Log.e(TAG, "Failed to start download", e);
    }

    @Override
    public void onClick(DialogInterface dialog, int which) {
        ArrayList<TrackKey> selectedTrackKeys = new ArrayList<>();
        for (int i = 0; i < representationList.getChildCount(); i++) {
            if (representationList.isItemChecked(i)) {
                selectedTrackKeys.add(trackKeys.get(i));
            }
        }
        if (!selectedTrackKeys.isEmpty() || trackKeys.isEmpty()) {
            // We have selected keys, or we're dealing with single stream content.
            SampleApplication.ampDownloadManager.startDownload(name, selectedTrackKeys);
        }
    }

}