package com.akamai.ampdemo;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.WindowManager;

import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.media.exowrapper2.DrmScheme;

import java.util.HashMap;

public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String LOG_TAG = "AMPv6";
    private final static String AMP_LICENSE = "BtvXWK8rlDMO8uWHJcnKB84uPUOQYCI8UKi9jGUgG5aGrKCdiKOsFVA00spK8fs7WDdZ9qNk5ztdMn1yWiam1g==";

    private final static String WIDEVINE_VIDEO_URL = "https://willzhanmswest.streaming.mediaservices.windows.net/609f4f57-1e5b-4898-90b1-81c574b2e8e3/VfE.ism/manifest(format=mpd-time-csf)";
    private static final String WIDEVINE_LICENSE_URL = "https://willzhanmswest.keydelivery.mediaservices.windows.net/Widevine/?kid=4c241420-4ec4-42cb-9551-e9eb988d2911";

    private final static String WIDEVINE_VIDEO_URL2 = "https://storage.googleapis.com/shaka-demo-assets/angel-one-widevine-hls/hls.m3u8";
    private static final String WIDEVINE_LICENSE_URL2 = "https://cwip-shaka-proxy.appspot.com/no_auth";

    private static final String PLAYREADY_VIDEO_URL = "http://playready.directtaps.net/smoothstreaming/SSWSS720H264PR/SuperSpeedway_720.ism";
    private static final String PLAYREADY_LICENSE_URL = null;



    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        videoPlayerContainer = findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);

        //addRequestHeaders();

        videoPlayerContainer.prepareResource(WIDEVINE_VIDEO_URL, DrmScheme.WIDEVINE, WIDEVINE_LICENSE_URL);
        //videoPlayerContainer.prepareResource(WIDEVINE_VIDEO_URL2, DrmScheme.WIDEVINE, WIDEVINE_LICENSE_URL2);
        //videoPlayerContainer.prepareResource(PLAYREADY_VIDEO_URL, DrmScheme.PLAYREADY, PLAYREADY_LICENSE_URL);
    }

    private void addRequestHeaders() {
        HashMap<String, String> headers = new HashMap<>();
        headers.put("TestHeader","TestValue-ABCDE-12345");
        headers.put("Authorization","Bearer=eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsIng1dCI6IkViRU1Bc25UcWphVlVvZy1uc1BNdzBEeF9LYyJ9.eyJncm91cHMiOiJiNmEyNTBmZi1mMjc3LTQwOTctYjg2Zi05MjFmYTYzODg1ZjYiLCJpc3MiOiJodHRwczovL3N0cy53aW5kb3dzLm5ldC81MTY0MWM0MC1hZDY1LTQ3MzYtODhmYy0yZjBlMTAwNzJkODUvIiwiYXVkIjoiMjk2MzVjZGMtY2E5YS00OGI3LWIyNDItMDVhMzE4MTBlOGM5IiwiZXhwIjoxNTQ0MTIxMTA4LCJuYmYiOjE1NDM1MTU3MDh9.qwidIHcXeoYOUlnOMJOh-ocbiOtqSz5_WWXGVf6JSnqnOyvLowNbqtr4brUd94ShxPSSd1iXedn-rNEJc8G5CYhkXR0Laygi_G9lqzPXm7t8CXtuGt7g5NxgHZLhmiE9kAQB0KyJfnHSqlN19-wbywEmoXUWx67r3XTgf1gQNgouF7gXtnoErsHhxAIxmoXRMJoBhw2aTEDP5pfYT65K9kBQ-gTEFTC3DlB3iqm5t3_azFdpu1bKw5QG-YmYMXNpKlPJeZ4XQQqNkp28JwoSg_W_BeBxgYH9tfVcyjHYK00oCjNRD9Fb0goEo2DAdVlZUg94AJS4WnvDeKdBqu6qZYlM__-AP3E-g9w_-EYGSl9WlUNRKa_B5Uj5hL_qPi4rcEa7rJsBN1TdaRPcRH18zKQR1KQIENnSKtz-QGPGaw9Ot6mb3nTGxG-E1fF7bgPrf6fMJPT8FZaE7Uk_eiEHPd9C46Koap4AkvZsCKoKHpX9n8p-nBWvcoebJscd2ATtNtRPTPtb6mzxFp3Pookwp_IihdjqT_mamwj0rVlGnL6RDb0iBxaPnWDfWlcqrq0pHXRRPDlcSuV09aIcpSmGx9zUlxvjXsurQkIDTaenpDk6r7zvItrZUw4C9IyNPXSCL-usOjQmSi_Dcv1KrKk7yL3bh-XSZuVTQOLfNH7Jhr8");
        videoPlayerContainer.setRequestHeaders(headers);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setLogEnabled(true);

        videoPlayerView.play(mediaResource);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception)
    {
        Log.e(LOG_TAG, "onResourceError()");
    }

    @Override
    protected void onResume() {
        Log.d(LOG_TAG, "onResume");
        if (videoPlayerView != null) videoPlayerView.onResume();
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(LOG_TAG, "onPause");
        if (videoPlayerView != null) videoPlayerView.onPause();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(LOG_TAG, "onDestroy");
        if (videoPlayerView != null) videoPlayerView.onDestroy();
        super.onDestroy();
    }

}
