package com.akamai.amp.demo;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.widget.Toast;

import com.akamai.amp.ads.fban.AmpFacebookAudienceNetworkManager;
import com.akamai.amp.AmpPlayer;
import com.akamai.amp.ads.yospace.AmpYospaceManager;
import com.akamai.amp.demo.helpers.ads.FacebookHelper;
import com.akamai.amp.demo.helpers.ads.FreewheelHelper;
import com.akamai.amp.demo.helpers.ads.YospaceHelper;
import com.akamai.amp.demo.helpers.analytics.AkamaiMediaHelper;
import com.akamai.amp.demo.helpers.analytics.GoogleHelper;
import com.akamai.amp.demo.helpers.analytics.FirebaseHelper;

import com.akamai.amp.demo.helpers.analytics.HeartbeatHelper;
import com.akamai.amp.demo.helpers.analytics.NielsenHelper;
import com.akamai.amp.demo.helpers.analytics.StreamsenseHelper;
import com.akamai.amp.analytics.adobeheartbeat.AmpAdobeHeartbeatAnalyticsTracker;
import com.akamai.amp.analytics.akamaimedia.AmpAkamaiMediaAnalyticsTracker;
import com.akamai.amp.analytics.comscorestreamsense.AmpComscoreStreamsenseAnalyticsTracker;
import com.akamai.amp.analytics.googleanalytics.AmpGoogleAnalyticsTracker;
import com.akamai.amp.analytics.nielsenanalytics.AmpNielsenDcrAnalyticsTracker;
import com.akamai.amp.ads.freewheel.AmpFreewheelManager;
import com.akamai.amp.ads.ima.AmpDAIManager;
import com.akamai.amp.ads.ima.AmpIMAManager;
import com.akamai.amp.ads.ima.DAI;
import com.akamai.amp.ads.ima.IMA;
import com.akamai.amp.uimobile.generic.listeners.IMediaPlayerControllerListener;

import static com.akamai.amp.AmpPlayerControlsOverlay.Mode;
import static com.akamai.amp.AmpPlayerControlsOverlay.State;

import com.akamai.amp.analytics.firebase.AmpFirebaseAnalyticsTracker;
import com.akamai.amp.analytics.firebase.AmpFirebaseEvent;
import com.akamai.amp.analytics.firebase.FirebaseTrackerData;


public class MainActivity extends Activity {

    /*
     * AMP's license takes into account the package name of your app and the expiration day.
     * This date can't be extended from Akamai's side, so be sure NOT to hardcode your license
     * into the app
     */
    private static final String AMP_LICENSE = "spOJe2QdcF0OLMdK8AL_Bewz7oQxb3MfrA3h__NT1ZJWyOmfzMWKlDgnraRTu9pUfmet8qWjmNR2lLBr3xsgrQ==";

    /*
     * Sample test streams
     */
    private static final String HLS_VOD = "https://media-demo-host.akamaized.net/test/video/kluge/hls/all.m3u8";
    private static final String HLS_LIVE = "http://multiformatlive-f.akamaihd.net/i/demostream_1@2131/master.m3u8";


    /*
     * AMP's main class
     */
    private AmpPlayer amp;

    /*
     * Usually an app has a single ad provider.
     * The parent interface of all the following is com.akamai.amp.ads.IAdsPlugin
     */
    private AmpIMAManager imaAds;
    private AmpDAIManager daiAds;
    private AmpFreewheelManager freewheelAds;
    private AmpYospaceManager yospaceAds;
    private AmpFacebookAudienceNetworkManager facebookAds;

    /*
     * Usually an app has several analytics trackers.
     * The parent class of all the following is com.akamai.amp.analytics.AnalyticsTracker
     */
    private AmpAkamaiMediaAnalyticsTracker akamaiMediaAnalytics;
    private AmpComscoreStreamsenseAnalyticsTracker streamsenseAnalytics;
    private AmpAdobeHeartbeatAnalyticsTracker heartbeatAnalytics;
    private AmpNielsenDcrAnalyticsTracker nielsenAnalytics;
    private AmpGoogleAnalyticsTracker googleAnalytics;

    private AmpFirebaseAnalyticsTracker firebaseAnalytics;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Ads providers
        imaAds = IMA.create(this);
        //daiAds = DAI.create(this);

        String mAds = "https://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpostpod&cmsid=496&vid=short_onecue&correlator=";
        //imaAds.setAdsUrl(mAds);

        //freewheelAds = FreewheelHelper.createManager(this);
        //yospaceAds = YospaceHelper.createManager(this);
        //facebookAds = FacebookHelper.createManager();


        // Analytics providers
      //  akamaiMediaAnalytics = new AmpAkamaiMediaAnalyticsTracker(AkamaiMediaHelper.buildData());
      //  streamsenseAnalytics = new AmpComscoreStreamsenseAnalyticsTracker(StreamsenseHelper.buildData());
     //   heartbeatAnalytics = new AmpAdobeHeartbeatAnalyticsTracker(HeartbeatHelper.buildData());
     //   nielsenAnalytics = new AmpNielsenDcrAnalyticsTracker(NielsenHelper.buildData());
     //   googleAnalytics = new AmpGoogleAnalyticsTracker(GoogleHelper.buildData());
     //   firebaseAnalytics = new AmpFirebaseAnalyticsTracker(FirebaseHelper.buildData());

        // AMP's main class instantiation
        amp = findViewById(R.id.amp);
        amp.configure(this, AMP_LICENSE, customButtonsCallback());
        amp.configureVisually(State.INLINE_PLAYER, Mode.INLINE, true, true);

        // Setting the plugins to AMP
        // Notice that AMP is set to function with a single ad provider and multiple analytics providers

        //amp.setAnalyticsPlugins(firebaseAnalytics);
        amp.setPlugins(imaAds);

        // Start DAI Playback
        //amp.prepareLiveStreamWithServerAds("sN_IYUG8STe1ZzhIIE_ksA");

        // Start playback
        // Notice this is not immediate, as the URL has to be retrieved and the stream has to be prepared)
        amp.prepare().withStream(HLS_VOD).withClientSideIMA(mAds).init();

    }


    /*
     * AMP needs to be aware of the Android lifecycle events.
     * The minimum necessary are onResume(), onPause() and onDestroy().
     */

    @Override
    public void onResume() {
        if (amp != null) amp.onResume();
        super.onResume();
    }

    @Override
    public void onPause() {
        if (amp != null) amp.onPause();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        if (amp != null) amp.onDestroy();
        super.onDestroy();
    }


    /*
     * This is a non mandatory sample of how to implement custom actions on specific UI clicks
     */
    private IMediaPlayerControllerListener customButtonsCallback() {
        return buttonId -> {
            switch (buttonId) {
                case IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_CLOSE:
                    showToast("CLOSE");
                    break;
                case IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_SHARE:
                    showToast("SHARE");
                    break;
                default:
                    break;
            }
        };
    }

    private void showToast(String message) {
        Context context = getApplication().getApplicationContext();
        Toast.makeText(context, message, Toast.LENGTH_LONG).show();
    }

}
