package com.akamai.amp.demo.helpers.analytics;


import com.akamai.amp.config.data.streamsense.StreamsenseAppData;
import com.akamai.amp.config.data.streamsense.StreamsenseClipLabels;
import com.akamai.amp.config.data.streamsense.StreamsenseData;
import com.akamai.amp.config.data.streamsense.StreamsensePlaylistLabels;
import com.akamai.amp.media.elements.AMPLibraryInfo;

import java.util.LinkedHashMap;
import java.util.Map;

public class StreamsenseHelper {

    public static StreamsenseData buildData() {
        StreamsenseData data = new StreamsenseData();
        data.setAppData(buildAppData());
        data.setPlaylistLabels(buildPlaylistLabels());
        data.setVideoLabels(buildVideoLabels());
        data.setAdLabels(buildAdLabels());
        return data;
    }

    public static StreamsenseAppData buildAppData() {
        StreamsenseAppData app = new StreamsenseAppData();
        app.setAppName(AMPLibraryInfo.NAME);
        app.setAppVersion(AMPLibraryInfo.VERSION);
        app.setPublisherId("1234567");
        app.setPublisherSecret("7b94840eb66b17e61c3d2f909c3a1163");
        return app;
    }

    private static StreamsensePlaylistLabels buildPlaylistLabels() {
        StreamsensePlaylistLabels p = new StreamsensePlaylistLabels();
        p.putValue("ns_st_pl", "My Playlist"); //1 Playlist Title
        p.putValue("ns_st_ca", "300000"); //2 Playlist Length (millis)
        p.putValue("ns_st_cp", "2"); //3 Total number of clips
        return p;
    }

    /*
     * Be sure to fill with your video's data. You can query the available labels with:
     * StreamsenseClipLabels.getAllMetadata() and StreamsenseClipLabels.getMandatoryMetadata()
     * Some fields will be automatically filled by AMP, for example the "ns_st_cl" (clip length)
     */
    private static StreamsenseClipLabels buildVideoLabels() {
        Map<String, String> m = new LinkedHashMap<>();

        m.put("ns_st_cn", "123"); //1 Clip Number
        m.put("ns_st_ci", "SampleCONTENT"); //2 Content ID
        m.put("ns_st_cl", "MANDATORY"); //3 Clip Length (millis)
        m.put("ns_st_pn", "MANDATORY"); //4 Part number
        m.put("ns_st_tp", "MANDATORY"); //5 Total parts
        //m.put("ns_st_el", "OPTIONAL"); //6 Episode Length (millis)
        m.put("ns_st_pu", "MANDATORY"); //7 Publisher Brand Name
        m.put("ns_st_pr", "MANDATORY"); //8 Program Title
        m.put("ns_st_ep", "MANDATORY"); //9 Episode Title
        m.put("ns_st_sn", "MANDATORY"); //10 Episode Season Number
        m.put("ns_st_en", "MANDATORY"); //11 Episode Number
        //m.put("ns_st_ty", "OPTIONAL"); //11 Stream Type
        m.put("ns_st_ge", "MANDATORY"); //12 Content Genre
        m.put("ns_st_ct", "MANDATORY"); //13 Classification Type
        m.put("ns_st_ti", "MANDATORY"); //14 TMS / Gracenote ID
        m.put("ns_st_ia", "MANDATORY"); //15 Ad Load Flag
        m.put("ns_st_ce", "MANDATORY"); //16 Complete Episode Flag (mandatory only for content)
        //m.put("ns_st_dt", "OPTIONAL"); //17 Production or creation Date
        //m.put("ns_st_tm", "OPTIONAL"); //18 Production or creation Time
        m.put("ns_st_ddt", "MANDATORY"); //19 Digital Airdate
        //m.put("ns_st_dtm", "OPTIONAL"); //20 Digital Airtime
        m.put("ns_st_tdt", "MANDATORY"); //21 TV Airdate
        //m.put("ns_st_ttm", "OPTIONAL"); //22 TV Airtime
        m.put("ns_st_st", "MANDATORY"); //23 Station Title
        //m.put("ns_st_fee", "OPTIONAL"); //24 Monetary Value
        //m.put("ns_st_ad", "OPTIONAL"); //25 Advertisement Flag (mandatory only for advertisements)
        //m.put("ns_st_li", "OPTIONAL"); //26 Live Flag (mandatory only for multicast, simulcast, or unicast streams)
        m.put("ns_st_ct", "MANDATORY"); //27 Classification Type
        //m.put("ns_st_cs", "OPTIONAL"); //28 Video Dimensions (640x480)
        //m.put("ns_st_cu", "OPTIONAL"); //29 Clip URL
        m.put("c3", "MANDATORY"); //30 Video Metrix dictionary classification values
        m.put("c4", "MANDATORY"); //31 Video Metrix dictionary classification values
        m.put("c6", "MANDATORY"); //32 Video Metrix dictionary classification values

        StreamsenseClipLabels l = new StreamsenseClipLabels();
        l.addValues(m);
        return l;
    }

    private static StreamsenseClipLabels buildAdLabels() {
        Map<String, String> m = new LinkedHashMap<>();

        m.put("ns_st_cn", "456"); //1 Clip Number
        m.put("ns_st_ci", "SampleAD"); //2 Content ID
        m.put("ns_st_cl", "10000"); //3 Clip Length (millis)
        m.put("ns_st_pn", "MANDATORY AD"); //4 Part number
        m.put("ns_st_tp", "MANDATORY AD"); //5 Total parts
        //m.put("ns_st_el", "OPTIONAL"); //6 Episode Length (millis)
        m.put("ns_st_pu", "MANDATORY"); //7 Publisher Brand Name
        m.put("ns_st_pr", "MANDATORY"); //8 Program Title
        m.put("ns_st_ep", "MANDATORY"); //9 Episode Title
        m.put("ns_st_sn", "MANDATORY"); //10 Episode Season Number
        m.put("ns_st_en", "MANDATORY"); //11 Episode Number
        //m.put("ns_st_ty", "OPTIONAL"); //11 Stream Type
        m.put("ns_st_ge", "MANDATORY"); //12 Content Genre
        m.put("ns_st_ct", "MANDATORY"); //13 Classification Type
        m.put("ns_st_ti", "MANDATORY"); //14 TMS / Gracenote ID
        m.put("ns_st_ia", "MANDATORY"); //15 Ad Load Flag
        m.put("ns_st_ce", "MANDATORY"); //16 Complete Episode Flag (mandatory only for content)
        //m.put("ns_st_dt", "OPTIONAL"); //17 Production or creation Date
        //m.put("ns_st_tm", "OPTIONAL"); //18 Production or creation Time
        m.put("ns_st_ddt", "MANDATORY"); //19 Digital Airdate
        //m.put("ns_st_dtm", "OPTIONAL"); //20 Digital Airtime
        m.put("ns_st_tdt", "MANDATORY"); //21 TV Airdate
        //m.put("ns_st_ttm", "OPTIONAL"); //22 TV Airtime
        m.put("ns_st_st", "MANDATORY"); //23 Station Title
        //m.put("ns_st_fee", "OPTIONAL"); //24 Monetary Value
        //m.put("ns_st_ad", "OPTIONAL"); //25 Advertisement Flag (mandatory only for advertisements)
        //m.put("ns_st_li", "OPTIONAL"); //26 Live Flag (mandatory only for multicast, simulcast, or unicast streams)
        m.put("ns_st_ct", "MANDATORY"); //27 Classification Type
        //m.put("ns_st_cs", "OPTIONAL"); //28 Video Dimensions (640x480)
        //m.put("ns_st_cu", "OPTIONAL"); //29 Clip URL
        m.put("c3", "MANDATORY"); //30 Video Metrix dictionary classification values
        m.put("c4", "MANDATORY"); //31 Video Metrix dictionary classification values
        m.put("c6", "MANDATORY"); //32 Video Metrix dictionary classification values

        StreamsenseClipLabels l = new StreamsenseClipLabels();
        l.addValues(m);
        return l;
    }

}
